==> cms-db_v0.5.1.tar.gz: admin/quirks-start.php <==
<?php
/*  cms-db  Copyright (C) 2007-2008 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1" />
		<title>cms -db Adminbereich</title>
		<link rel="stylesheet" type="text/css" href="style.css" />
		<style type="text/css">
		<!--
		a:link, a:visited, a:active, a:hover {
			border: 10px solid #ffffff;
		}
		/*a:hover {
			border-top: 10px solid #ffffff;
			border-left: 10px solid #0000ff;
			border-right: 10px solid #0000ff;
			border-bottom: 10px solid #ffffff;
		}*/
		img {
			vertical-align: middle;
			padding: 1px;
		}
		-->
		</style>
	</head>
	<body>
		<h1>Startseite</h1>
		<p>
			<a href="pages.php?<?php echo SID ?>" title="Seitenverwaltung" style="text-decoration:none">
				<img src="big-icons/pages.png" alt="Seitenverwaltung" width="48" height="48" style="border:none" />
			</a>
			<a href="files.php?<?php echo SID ?>" title="Dateiverwaltung" style="text-decoration:none">
				<img src="big-icons/files.png" alt="Dateiverwaltung" width="48" height="48" style="border:none" />
			</a>
			<a href="includes.php?<?php echo SID ?>" title="Verwaltung von Include-Dateien" style="text-decoration:none">
				<img src="big-icons/includes.png" alt="Verwaltung von Include-Dateien" width="48" height="48" style="border:none" />
			</a>
			<a href="settings.php?<?php echo SID ?>" title="Einstellungen &auml;ndern" style="text-decoration:none">
				<img src="big-icons/settings.png" alt="Einstellungen &auml;ndern" width="48" height="48" style="border:none" />
			</a>
			<a href="template.php?<?php echo SID ?>" title="Template/Design bearbeiten" style="text-decoration:none">
				<img src="big-icons/template.png" alt="Template/Design bearbeiten" width="48" height="48" style="border:none" />
			</a>
			<a href="space.php?<?php echo SID ?>" title="Speicherplatzinformation" style="text-decoration:none">
				<img src="big-icons/space.png" alt="Speicherplatzinformationen" width="48" height="48" style="border:none" />
			</a>
			<a href="fileperms.php?<?php echo SID ?>" title="Dateirechteverwaltung" style="text-decoration:none">
				<img src="big-icons/fileperms.png" alt="Dateirechteverwaltung" width="48" height="48" style="border:none" />
			</a>
			<a href="backup.php?<?php echo SID ?>" title="Sicherheitskopien erstellen" style="text-decoration:none">
				<img src="big-icons/backup.png" alt="Sicherheitskopien erstellen" width="48" height="48" style="border:none" />
			</a>
			<a href="guestbook.php?<?php echo SID ?>" title="G&auml;stebucheintr&auml;ge l&ouml;schen" style="text-decoration:none">
				<img src="big-icons/guestbook.png" alt="G&auml;stebucheintr&auml;ge l&ouml;schen" width="48" height="48" style="border:none" />
			</a>
			<a href="stats.php?<?php echo SID ?>" title="Browser- und Betriebssystem-Statistik ansehen" style="text-decoration:none">
				<img src="big-icons/stats.png" alt="Browser- und Betriebssystem-Statistik ansehen" width="48" height="48" style="border:none" />
			</a>
			<a href="recyclebin.php?<?php echo SID ?>" title="Gel&ouml;schte Objekte wiederherstellen" style="text-decoration:none">
				<img src="big-icons/recyclebin.png" alt="Gel&ouml;schte Objekte wiederherstellen" width="48" height="48" style="border:none" />
			</a>
		</p>
		<?php
		if (ini_get('safe_mode')) {
			echo '<p>Es m&uuml;ssen Angaben bei den FTP-Einstellungen eingestellt werden!<br><a href="ftpsettings.php">einstellen</a></p>';
		}
		?>
	</body>
</html>

==> cms-db_v0.7.9.tar.gz: admin/quirks-start.php <==
<?php
/*  cms-db  Copyright (C) 2007-2008 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<title>cms -db Adminbereich</title>
		<link rel="stylesheet" type="text/css" href="style.css" />
		<style type="text/css">
		<!--
		a:link, a:visited, a:active, a:hover {
			border: 10px solid #ffffff;
		}
		a:hover {
			border-top: 10px solid #ffffff;
			border-left: 10px solid #0000ff;
			border-right: 10px solid #0000ff;
			border-bottom: 10px solid #ffffff;
		}
		img {
			vertical-align: middle;
			padding: 1px;
		}
		-->
		</style>
	</head>
	<body>
		<h1>Startseite</h1>
		<p>
			<a href="pages.php?<?php echo SID ?>" title="Seitenverwaltung" style="text-decoration:none">
				<img src="big-icons/pages.png" alt="Seitenverwaltung" width="48" height="48" style="border:none" />
			</a>
			<a href="files.php?<?php echo SID ?>" title="Dateiverwaltung" style="text-decoration:none">
				<img src="big-icons/files.png" alt="Dateiverwaltung" width="48" height="48" style="border:none" />
			</a>
			<a href="includes.php?<?php echo SID ?>" title="Verwaltung von Include-Dateien" style="text-decoration:none">
				<img src="big-icons/includes.png" alt="Verwaltung von Include-Dateien" width="48" height="48" style="border:none" />
			</a>
			<a href="settings.php?<?php echo SID ?>" title="Einstellungen &auml;ndern" style="text-decoration:none">
				<img src="big-icons/settings.png" alt="Einstellungen &auml;ndern" width="48" height="48" style="border:none" />
			</a>
			<a href="template.php?<?php echo SID ?>" title="Template/Design bearbeiten" style="text-decoration:none">
				<img src="big-icons/template.png" alt="Template/Design bearbeiten" width="48" height="48" style="border:none" />
			</a>
			<a href="space.php?<?php echo SID ?>" title="Speicherplatzinformation" style="text-decoration:none">
				<img src="big-icons/space.png" alt="Speicherplatzinformationen" width="48" height="48" style="border:none" />
			</a>
			<a href="fileperms.php?<?php echo SID ?>" title="Dateirechteverwaltung" style="text-decoration:none">
				<img src="big-icons/fileperms.png" alt="Dateirechteverwaltung" width="48" height="48" style="border:none" />
			</a>
			<a href="backup.php?<?php echo SID ?>" title="Sicherheitskopien erstellen" style="text-decoration:none">
				<img src="big-icons/backup.png" alt="Sicherheitskopien erstellen" width="48" height="48" style="border:none" />
			</a>
			<a href="guestbook.php?<?php echo SID ?>" title="G&auml;stebucheintr&auml;ge l&ouml;schen" style="text-decoration:none">
				<img src="big-icons/guestbook.png" alt="G&auml;stebucheintr&auml;ge l&ouml;schen" width="48" height="48" style="border:none" />
			</a>
			<a href="stats.php?<?php echo SID ?>" title="Browser- und Betriebssystem-Statistik ansehen" style="text-decoration:none">
				<img src="big-icons/stats.png" alt="Browser- und Betriebssystem-Statistik ansehen" width="48" height="48" style="border:none" />
			</a>
			<a href="recyclebin.php?<?php echo SID ?>" title="Gel&ouml;schte Objekte wiederherstellen" style="text-decoration:none">
				<img src="big-icons/recyclebin.png" alt="Gel&ouml;schte Objekte wiederherstellen" width="48" height="48" style="border:none" />
			</a>
		</p>
		<?php
		if (ini_get('safe_mode')) {
			echo '<p>Es m&uuml;ssen Angaben bei den FTP-Einstellungen eingestellt werden!<br><a href="ftpsettings.php">einstellen</a></p>';
		}
		?>
	</body>
</html>
